@@ -3,5 +3,5 @@
 """Top-level package for Conventional Commit Sphinx Changelog."""
 
 __author__ = """Paul Gierz"""
-__email__ = 'pgierz@awi.de'
-__version__ = '0.5.0'
+__email__ = "pgierz@awi.de"
+__version__ = "0.5.2"
